@@ -23,7 +23,7 @@ URL = 'https://erdogant.github.io/datasets/graphviz-2.38.zip'
 
 
 # %% Plot tree
-def plot(model, featnames=None, num_trees=0, figsize=(25,25), verbose=3):
+def plot(model, featnames=None, num_trees=0, plottype='horizontal', figsize=(25,25), verbose=3):
     """Make tree plot for the input model.
 
     Parameters
@@ -34,6 +34,10 @@ def plot(model, featnames=None, num_trees=0, figsize=(25,25), verbose=3):
         list of feature names. The default is None.
     num_trees : int, default 0
         Specify the ordinal number of target tree
+    plottype : str, (default : 'horizontal')
+        Works only in case of xgb model.
+        * 'horizontal'
+        * 'vertical'
     figsize: tuple, default (25,25)
         Figure size, (height, width)
     verbose : int, optional
@@ -46,17 +50,18 @@ def plot(model, featnames=None, num_trees=0, figsize=(25,25), verbose=3):
         Figure axis of the input model.
 
     """
-    modelname=str(model).lower()
+    modelname = str(model).lower()
     if ('xgb' in modelname):
         if verbose>=4: print('xgboost plotting pipeline.')
-        ax=xgboost(model, featnames=featnames, num_trees=num_trees, figsize=figsize, verbose=verbose)
+        ax = xgboost(model, featnames=featnames, num_trees=num_trees, figsize=figsize, plottype=plottype, verbose=verbose)
     elif ('tree' in modelname) or ('forest' in modelname) or ('gradientboosting' in modelname):
         if verbose>=4: print('tree plotting pipeline.')
-        ax=randomforest(model, featnames=featnames, num_trees=num_trees, figsize=figsize, verbose=verbose)
+        ax = randomforest(model, featnames=featnames, num_trees=num_trees, figsize=figsize, verbose=verbose)
     else:
         print('[treeplot] Model %s not recognized.' %(modelname))
+        ax = None
 
-    return(ax)
+    return ax
 
 
 # %% Plot tree
